#
# spec file for package ngrep
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define tarver 1_47
Name:           ngrep
Version:        1.47
Release:        3.3
Summary:        Network grep
License:        BSD-4-Clause
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/jpr5/ngrep
Source:         https://github.com/jpr5/ngrep/archive/V%{tarver}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: Switch from PCRE to PCRE2 (https://github.com/jpr5/ngrep/pull/27)
Patch0:         27.patch
BuildRequires:  libpcap-devel
BuildRequires:  pcre2-devel

%description
ngrep strives to provide most of GNU grep's common features, applying them
to the network layer. ngrep is a pcap-aware tool that allows you to specify
extended regular or hexadecimal expressions to match against data payloads
of packets. It currently recognizes IPv4/6, TCP, UDP, ICMPv4/6, IGMP and
Raw across Ethernet, PPP, SLIP, FDDI, Token Ring and null interfaces, and
understands BPF filter logic in the same fashion as more common packet
sniffing tools, such as tcpdump and snoop.

%prep
%autosetup -p1 -n %{name}-%{tarver}

%build
%configure \
    --enable-pcre2 \
    --enable-ipv6 \
    --with-pcap-includes=%{_includedir}/pcap

make %{?_smp_mflags}

%install
%make_install

%files
%{_bindir}/%{name}
%{_mandir}/man8/%{name}.8%{ext_man}

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Sep 23 2022 Stephan Kulow <coolo@suse.com>
- Cherry picking PR 27.patch from github to switch to PCRE2 (project
  seems dead unfortunately) - rebased though
* Sun Dec 31 2017 avindra@opensuse.org
- Update to version 1.47
  * Fix "no VLAN support for XXX"-related problems
  * Fix truncated/garbled output (e.g. SIP over SLL/Linux cooked
    sockets)
  * Change exit behavior to match BSD & GNU grep (see manpage)
  * Add Solaris IPnet support
  * Update to use 32bit values where relevant
  * Emit frame # in header, useful for reference/analysis
  * Emit total received, matched upon exit (dropped unreliable
    PCAP stats)
  * Import debian patches related to autotools, manpage, and
    compilation on other platforms
  * Fix build clean/distclean when not linked against provided
    GNU regex
  * Fix build --enable/--disable flag processing
  * Update to latest autotools (2017)
  * Fix building under MS VS2012 / Win32
- cleanup with spec-cleaner
- drop 10_man-fixes.diff
  * upstreamed in 8e5187def73abd624c10ed37d42b7416e4a1ce97
- tcpkill compilation disabled due to incompatiblity with modern
  libnet
- remove future tense in description
* Wed Mar 15 2017 dimstar@opensuse.org
- Dol not pass --disable-pcap-restart to configure: this is the
  default and the configure check is quite broken in processing it:
  - -disable-pcap-restarted is treated equal to --enable-pcap-restart.
* Tue Dec  1 2015 p.drouand@gmail.com
- Update to version 1.46.1
  * actual bugfix for the VLAN parsing issue.  prior version 1.46 expanded
    the BPF filter to include IPv4/6 traffic, but the offset calculation
    forgot to account for the variable presence of VLAN headers.  now
    ngrep detects VLAN frames in every packet and adjusts the offset on
    the fly.
- Changes from version 1.46
  * configure.in: re-organized, in part t  * sync with downstream patches
    (which were never sent upstream)
  * configure.in: removed included PCRE library, now builds against system
    version when specified (default is included GNU Regex)
  * configure.in: fixed duplicate PCAP header check, which broke with the
    release of libpcap 1.0
  * configure.in: prefixed all tack-on autoconf variables from _FO  * -> EXTRA_FOO
  * Makefile.in: capitulated t  * Debian: use tar.gz instead of tar.bz2
  * ngrep.c: Call setlocale t  * make isprint() work based on current
    locale (bdo#307496).
  * include tcpkill functionality (-K), a long-standing downstream patch
    under Debian
  * updated t  * latest autoconf
  * updated copyrights t  * 2014
- Remove obsolete patches
  * 10_debian-build.diff
  * 20_setlocale.diff
  * 40_ipv6-offsets.diff
- Update project Url
- Use download Url
- Enable tcpkill function with "--enable-tcpkill" configure switch
  and add libnet-devel build dependency for openSUSE > 12.1
* Sun Jul 13 2014 adam@mizerski.pl
- Copied debian patches
  - 10_debian-build.diff
  - 10_man-fixes.diff
  - 20_setlocale.diff
  - 40_ipv6-offsets.diff
- Fixed pcap usage. See
  https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=546596
- Enabled IPv6 support.
- Usage of system provided pcre library.
- Disabled automatic stripping of executable.
- Added CHANGES.txt CREDITS.txt README.txt and LICENSE.txt files
  to packaged documentation.
- Spec file cleanup.
* Thu May 31 2012 pcerny@suse.com
- corrected licence
* Tue Aug 26 2008 lchiquitto@novell.com
- First version (1.45)
